@@ -8,6 +8,13 @@ from tencentcloud.tmt.v20180321 import tmt_client, models
 
 class Translate:
     def __init__(self, scid=pre_check('txyun_scid'), sckey=pre_check('txyun_sckey'), region=pre_check('txyun_df_region')):
+        """
+        初始化并登陆腾讯翻译接口
+
+        :param scid: secret id
+        :param sckey: secret key
+        :param region: 地区
+        """
         cred = credential.Credential(scid, sckey)
         http_profile = HttpProfile()
         http_profile.endpoint = "tmt.tencentcloudapi.com"
@@ -16,6 +23,12 @@ class Translate:
         self.client = tmt_client.TmtClient(cred, region, clientProfile)
 
     def langdetect(self, text):
+        """
+        获取文本的语言类型
+
+        :param text: 待识别文本
+        :return: 语言类型
+        """
         req = models.LanguageDetectRequest()
         req.from_json_string(json.dumps({
             "Text": text[:len(text) // 2],
@@ -24,6 +37,12 @@ class Translate:
         return json.loads(self.client.LanguageDetect(req).to_json_string())['Lang']
 
     def translate(self, text: str):
+        """
+        翻译文本至中文
+
+        :param text: 文本
+        :return: 翻译结果
+        """
         req = models.TextTranslateRequest()
         req.from_json_string(json.dumps({
             "SourceText": text,
